/* global AutoSliderCaptions, AutoVars */

// config
require.config( {
	paths: {
		jquery:     'assets/js/fix.jquery',
		underscore: 'assets/js/fix.underscore',
		util:       'bower_components/bootstrap/dist/js/umd/util',
		alert:      'bower_components/bootstrap/dist/js/umd/alert',
		button:     'bower_components/bootstrap/dist/js/umd/button',
		carousel:   'bower_components/bootstrap/dist/js/umd/carousel',
		collapse:   'bower_components/bootstrap/dist/js/umd/collapse',
		dropdown:   'bower_components/bootstrap/dist/js/umd/dropdown',
		modal:      'bower_components/bootstrap/dist/js/umd/modal',
		scrollspy:  'bower_components/bootstrap/dist/js/umd/scrollspy',
		tab:        'bower_components/bootstrap/dist/js/umd/tab',
		tooltip:    'bower_components/bootstrap/dist/js/umd/tooltip',
		popover:    'bower_components/bootstrap/dist/js/umd/popover',
		stampit:    'assets/js/vendor/stampit',
	}
} );

require.config( {
	baseUrl: AutoVars.pathToTheme
} );

require( [
		'jquery',
		'underscore',
		'assets/js/utils/isElementInView',
		'assets/js/utils/objectFitFallback',
		'assets/js/WidgetLine',
		'assets/js/portfolio-grid-filter/gridFilter',
		'assets/js/portfolio-grid-filter/sliderFilter',
		'vendor/proteusthemes/proteuswidgets/assets/js/NumberCounter',
		'vendor/proteusthemes/sticky-menu/assets/js/sticky-menu',
		'assets/js/TouchDropdown',
		'carousel',
		'collapse',
		'tab',
], function ( $, _, isElementInView, objectFitFallback, WidgetLine, gridFilter, sliderFilter, NumberCounter ) {
	'use strict';

	/**
	 * Footer widgets fix
	 */
	$( '.col-lg-__col-num__' ).removeClass( 'col-lg-__col-num__' ).addClass( 'col-lg-3' );

	/**
	 * Widget lines, the length is relative to the amount of text
	 */
	$( '.widget-title--big .widget-title' ).each( function () {
		new WidgetLine( $( this ) );
	} );

	/**
	 * Animate the scroll, when back to top is clicked
	 */
	(function backToTop() {
		$('.footer-middle__back-to-top').click(function (ev) {
			ev.preventDefault();

			$('body, html').animate({
				scrollTop: 0
			}, 700);
		});
	})();

	/**
	 * Main slider controls
	 */
	(function slider () {
		var $slider = $('.js-jumbotron-slider'),
			$captions = {
				container: $('.js-slider-captions'),
				title:     $('.js-slider-captions__title'),
				text:      $('.js-slider-captions__text'),
			},
			transitionClass = 'is-in-transition',
			transitionTime = 600; // in ms

		// Captions for the main slider - change them in the out-of-the-bounds element
		if ( $slider.length && 'object' === typeof AutoSliderCaptions ) {
			$slider.on('slide.bs.carousel', function (ev) {
				var nextIndex = $(ev.relatedTarget).index();

				$captions.container.addClass(transitionClass);

				setTimeout(_.bind(function () {
					$captions.title.text(AutoSliderCaptions[nextIndex].title);
					$captions.text.html(AutoSliderCaptions[nextIndex].text);
				}, this), (transitionTime / 2));
			});

			$slider.on('slid.bs.carousel', function () {
				$captions.container.removeClass(transitionClass);
			});
		}

		// Pause the carousel if it's not visible
		if ($slider.length) {
			$(document).on('scroll', _.throttle(function () {
				if (isElementInView($slider)) {
					$slider.carousel('cycle');
				}
				else {
					$slider.carousel('pause');
				}
			}, 1000, {leading: false}));
		}
	})();

	/**
	 * Portfolio grid filtering
	 */
	$('.portfolio-grid').each(function () {
		var hash = window.location.hash,
			portfolioGrid;

		if ('slider' === $(this).data('type')) {
			portfolioGrid = sliderFilter({
				$container: $(this),
			});
		}
		else {
			portfolioGrid = gridFilter({
				$container: $(this),
			});
		}

		// Getting on visit or if "All" nav button is disabled.
		if ( new RegExp('^#' + portfolioGrid.hashPrefix).test(hash) ) {
			$(this).find('a[href="' + hash.replace(portfolioGrid.hashPrefix, '') + '"]').trigger('click');
		}
		else if ( $(this).find('.portfolio-grid__nav-item:nth-child(2)').hasClass('is-disabled') ) {
			// Trigger click for the third nav grid item, if the "All" nav button is missing.
			$(this).find('.portfolio-grid__nav-item:nth-child(3)').children('.portfolio-grid__nav-link')
				.data( 'skip-hash-update', true )
				.trigger( 'click' )
				.removeData( 'skip-hash-update' );
		}

		// Recalculate the mobile nav height, if the "All" nav button is disabled. Fix for both cases above.
		if ( ! portfolioGrid.isDesktopLayout() && $(this).find('.portfolio-grid__nav-item:nth-child(2)').hasClass('is-disabled') ) {
			portfolioGrid.initNavHolderHeight();
		}
	});

	/**
	 * Number Counter Widget JS code
	 */

	// Get all number counter widgets
	var $counterWidgets = $( '.number-counters' );

	if ( $counterWidgets.length ) {

		// jQuery easing function: easeInOutQuad, for use in NumberCounter
		// URL of easing functions: https://github.com/gdsmith/jquery.easing/blob/master/jquery.easing.js
		$.extend( $.easing, {
			easeInOutQuad: function (x, t, b, c, d) {
				if ((t/=d/2) < 1) {
					return c/2*t*t + b;
				}
				return -c/2 * ((--t)*(t-2) - 1) + b;
			}
		});

		$counterWidgets.each( function () {
			new NumberCounter( $( this ) );
		} );
	}

	/**
	 * Icon Box with Popover Widget JS code
	 */
	$(document).on('click', '.js-popover-icon-box', function(event) {
		event.preventDefault();
		$(this).toggleClass('popover-icon-box--active');
	});

} );
