<?php
/**
 * Filters for Auto WP theme
 *
 * @package auto-pt
 */

/**
 * AutoPTFilters class with filter hooks
 */
class AutoPTFilters {

	function __construct() {
		// Add shortcodes in widgets.
		add_filter( 'widget_text', 'do_shortcode' );

		// ProteusWidgets.
		add_filter( 'pw/widget_views_path', array( $this, 'set_widgets_view_path' ) );
		add_filter( 'pw/testimonial_widget', array( $this, 'set_testimonial_settings' ) );
		add_filter( 'pw/featured_page_widget_page_box_image_size', array( $this, 'set_page_box_image_size' ) );
		add_filter( 'pw/featured_page_widget_inline_image_size', array( $this, 'set_inline_image_size' ) );
		add_filter( 'pw/featured_page_excerpt_lengths', array( $this, 'set_featured_page_excerpt_lengths' ) );
		add_filter( 'pw/social_icons_fa_icons_list', array( $this, 'social_icons_fa_icons_list' ) );
		add_filter( 'pw/default_social_icon', array( $this, 'default_social_icon' ) );
		add_filter( 'pw/icon_box_widget', array( $this, 'set_icon_box_settings' ) );
		add_filter( 'pw/featured_page_fields', array( $this, 'set_featured_page_fields' ) );
		add_filter( 'pw/steps_widget_settings', array( $this, 'set_steps_widget_settings' ) );

		// Custom tag font size.
		add_filter( 'widget_tag_cloud_args', array( $this, 'set_tag_cloud_sizes' ) );

		// Custom text after excerpt.
		add_filter( 'excerpt_more', array( $this, 'excerpt_more' ) );

		// Footer widgets with dynamic layouts.
		add_filter( 'dynamic_sidebar_params', array( $this, 'footer_widgets_params' ), 9, 1 );

		// Google fonts.
		add_filter( 'autopt_pre_google_web_fonts', array( $this, 'additional_fonts' ) );
		add_filter( 'autopt_subsets_google_web_fonts', array( $this, 'subsets_google_web_fonts' ) );

		// Page builder.
		add_filter( 'siteorigin_panels_widget_style_fields', array( $this, 'add_fields_to_pagebuilder_widget_panel' ) );
		add_filter( 'siteorigin_panels_widget_style_attributes', array( $this, 'add_attributes_to_pagebuilder_widget_panel' ), 10, 2 );
		add_filter( 'siteorigin_panels_settings_defaults', array( $this, 'siteorigin_panels_settings_defaults' ) );
		add_filter( 'siteorigin_panels_widgets', array( $this, 'add_icons_to_page_builder_for_pw_widgets' ), 15 );
		add_filter( 'siteorigin_panels_widget_dialog_tabs', array( $this, 'siteorigin_panels_add_widgets_dialog_tabs' ), 15 );

		// SiteOrigin custom widgets.
		add_filter( 'siteorigin_widgets_widget_folders', array( $this, 'siteorigin_widgets_widget_folders' ) );
		add_filter( 'siteorigin_widgets_template_file_pw_open_position', array( $this, 'siteorigin_widgets_template_file_pw_open_position' ) );
		add_filter( 'admin_init', array( $this, 'siteorigin_widgets_active_widgets' ) );

		// Embeds.
		add_filter( 'embed_oembed_html', array( $this, 'embed_oembed_html' ), 10, 1 );

		// Protocols.
		add_filter( 'kses_allowed_protocols', array( $this, 'kses_allowed_protocols' ) );

		// ProteusThemes Shortcodes (plugin).
		add_filter( 'pt-shortcodes/button_shortcode_attributes', array( $this, 'pt_button_shortcode_attributes' ) );
		add_filter( 'pt-shortcodes/button_shortcode_output', array( $this, 'pt_button_shortcode_output' ), 10, 3 );

		// One Click Demo Import plugin
		add_filter( 'pt-ocdi/import_files', array( $this, 'ocdi_import_files' ) );
		add_action( 'pt-ocdi/after_import', array( $this, 'ocdi_after_import_setup' ) );
		add_filter( 'pt-ocdi/message_after_file_fetching_error', array( $this, 'ocdi_message_after_file_fetching_error' ) );

		// Sticky menu.
		add_filter( 'pt-sticky-menu/mobile_menu_button_class', array( $this, 'pt_sticky_menu_mobile_menu_button_class' ) );

		// Remove references to SiteOrigin Premium.
		add_filter( 'siteorigin_premium_upgrade_teaser', '__return_false' );

		// WPML filters.
		add_filter( 'wpml_duplicate_generic_string', array( $this, 'wpml_change_proteus_widget_ids_upon_duplication' ), 10, 3 );
	}


	/**
	 * Filter the Testimonial widget fields that the Auto theme will need from ProteusWidgets - Tesimonial widget
	 */
	function set_testimonial_settings( $attr ) {
		$attr['number_of_testimonial_per_slide'] = 2;
		$attr['rating']                          = false;
		$attr['author_description']              = true;
		$attr['author_avatar']                   = false;
		$attr['bootstrap_version']               = 4;
		return $attr;
	}

	/**
	 * Custom tag font size
	 */
	function set_tag_cloud_sizes( $args ) {
		$args['smallest'] = 14;
		$args['largest']  = 14;
		$args['unit'] = 'px';
		return $args;
	}


	/**
	 * Custom text after excerpt
	 */
	function excerpt_more( $more ) {
		return ' &hellip;';
	}


	/**
	 * Filter the dynamic sidebars and alter the BS col classes for the footer wigets
	 *
	 * @param  array $params
	 * @return array
	 */
	function footer_widgets_params( $params ) {
		static $counter              = 0;
		static $first_row            = true;
		$footer_widgets_layout_array = AutoPTHelpers::footer_widgets_layout_array();

		if ( 'footer-widgets' === $params[0]['id'] ) {
			$increase_counter = true;

			if ( defined( 'ICL_LANGUAGE_CODE' ) ) { // WPML is active
				$widget_type = preg_replace( '/-\d+$/', '', $params[0]['widget_id'] );
				$lang_of_widget = get_option( 'widget_' . $widget_type )[ $params[1]['number'] ]['wpml_language'];

				if ( $lang_of_widget != ICL_LANGUAGE_CODE ) {
					$increase_counter = false;
				}
			}

			// 'before_widget' contains __col-num__, see inc/theme-sidebars.php.
			$params[0]['before_widget'] = str_replace( '__col-num__', $footer_widgets_layout_array[ $counter ], $params[0]['before_widget'] );

			// First widget in the any non-first row.
			if ( false === $first_row && 0 === $counter ) {
				$params[0]['before_widget'] = '</div><div class="row">' . $params[0]['before_widget'];
			}

			if ( $increase_counter ) {
				$counter++;
			}
		}

		end( $footer_widgets_layout_array );
		if ( $counter > key( $footer_widgets_layout_array ) ) {
			$counter   = 0;
			$first_row = false;
		}

		return $params;
	}


	/**
	 * Filter setting ProteusWidgets mustache widget views path for Auto
	 */
	function set_widgets_view_path() {
		return get_template_directory() . '/inc/widgets-views';
	}


	/**
	 * Filter the Featured page widget pw-page-box image size for Auto (ProteusWidgets)
	 */
	function set_page_box_image_size( $image ) {
		$image['width']  = 360;
		$image['height'] = 180;
		return $image;
	}


	/**
	 * Filter the Featured page widget pw-page-box image size for Auto (ProteusWidgets)
	 */
	function default_social_icon( $image ) {
		return 'fa-linkedin-square';
	}


	/**
	 * Filter the Featured page widget pw-page-box image size for Auto (ProteusWidgets)
	 */
	function set_icon_box_settings( $settings ) {
		$settings['featured_setting'] = true;
		return $settings;
	}


	/**
	 * Filter the Featured page widget pw-inline image size for Auto (ProteusWidgets)
	 */
	function set_inline_image_size( $image ) {
		$image['width']  = 100;
		$image['height'] = 70;
		return $image;
	}

	/**
	 * Filter the Featured page widget excerpt lengths for Auto (ProteusWidgets)
	 */
	function set_featured_page_excerpt_lengths( $excerpt_lengths ) {
		$excerpt_lengths['inline_excerpt']  = 55;
		$excerpt_lengths['block_excerpt']   = 140;
		return $excerpt_lengths;
	}

	/**
	 * Filter for the list of Font-Awesome icons in social icons widget in Auto (ProteusWidgets)
	 */
	function social_icons_fa_icons_list() {
		return array(
			'fa-facebook',
			'fa-twitter',
			'fa-youtube',
			'fa-google-plus',
			'fa-pinterest',
			'fa-tumblr',
			'fa-xing',
			'fa-vimeo',
			'fa-linkedin',
			'fa-rss',
			'fa-github',
			'fa-bitbucket',
		);
	}

	/**
	 * Return Google fonts and sizes
	 *
	 * @see https://github.com/grappler/wp-standard-handles/blob/master/functions.php
	 * @return array Google fonts and sizes.
	 */
	function additional_fonts( $fonts ) {

		/* translators: If there are characters in your language that are not supported by Exo and Roboto, translate this to 'off'. Do not translate into your own language. */
		if ( 'off' !== esc_html_x( 'on', 'Exo and Roboto: on or off', 'auto-pt' ) ) {
			$fonts['Exo'] = array(
				'800' => '800',
			);
			$fonts['Roboto'] = array(
				'400' => '400',
				'700' => '700',
			);
		}

		return $fonts;
	}


	/**
	 * Add subsets from customizer, if needed.
	 *
	 * @return array
	 */
	function subsets_google_web_fonts( $subsets ) {
		$additional_subset = get_theme_mod( 'charset_setting', 'latin' );

		array_push( $subsets, $additional_subset );

		return $subsets;
	}


	/**
	 * Add the "featured widget" checkbox to the PageBuilder widget panel under Design section.
	 *
	 * @link https://siteorigin.com/docs/page-builder/hooks/custom-row-settings/
	 * @param $fields Array of all existing (default) PageBuilder widget settings fields
	 * @return array
	 */
	function add_fields_to_pagebuilder_widget_panel( $fields ) {
		$fields['bigger_title'] = array(
			'name'     => esc_html__( 'Widget Title', 'auto-pt' ),
			'type'     => 'checkbox',
			'label'    => esc_html__( 'Exposed title (bigger font, thin line)', 'auto-pt' ),
			'group'    => 'design',
			'priority' => 18,
		);

		return $fields;
	}


	/**
	 * Add the functionality of the above "featured widget" checkbox
	 *
	 * @link https://siteorigin.com/docs/page-builder/hooks/custom-row-settings/
	 * @param $attributes Array of all attributes that get applied to the widget on front-end
	 * @param $args Array of all settings from the widget panel
	 * @return array
	 */
	function add_attributes_to_pagebuilder_widget_panel( $attributes, $args ) {
		if ( empty( $attributes['class'] ) ) {
			$attributes['class'] = array();
		}

		if ( ! empty( $args['bigger_title'] ) ) {
			$attributes['class'][] = 'widget-title--big';
		}

		return $attributes;
	}


	/**
	 * Embedded videos and video container around them
	 */
	function embed_oembed_html( $html ) {
		if (
			false !== strstr( $html, 'youtube.com' ) ||
			false !== strstr( $html, 'wordpress.tv' ) ||
			false !== strstr( $html, 'wordpress.com' ) ||
			false !== strstr( $html, 'vimeo.com' )
		) {
			$out = '<div class="embed-responsive  embed-responsive-16by9">' . $html . '</div>';
		} else {
			$out = $html;
		}
		return $out;
	}


	/**
	 * Add more allowed protocols
	 *
	 * @link https://developer.wordpress.org/reference/functions/wp_allowed_protocols/
	 */
	static function kses_allowed_protocols( $protocols ) {
		return array_merge( $protocols, array( 'skype' ) );
	}


	/**
	 * Change the default settings for SO
	 *
	 * @param  array $settings
	 * @return array
	 */
	function siteorigin_panels_settings_defaults( $settings ) {
		$settings['title-html'] = '<h3 class="widget-title"><span class="widget-title__inline">{{title}}</span></h3>';
		$settings['full-width-container'] = '.boxed-container';
		$settings['mobile-width'] = '991';

		return $settings;
	}


	/**
	 * Set SiteOrigin custom widgets folder
	 */
	function siteorigin_widgets_widget_folders( $folders ) {
		$folders[] = get_template_directory() . '/inc/so-widgets/';
		return $folders;
	}


	/**
	 * Set SiteOrigin template for Open Position widget
	 */
	function siteorigin_widgets_template_file_pw_open_position( $template_file ) {
		return get_template_directory() . '/inc/so-widgets/widget-open-position/tpl/open-position-template.php';
	}


	/**
	 * Activate SiteOrigin custom widgets
	 */
	function siteorigin_widgets_active_widgets() {
		if ( ! get_theme_mod( 'so_custom_widgets_activated' ) && class_exists( 'SiteOrigin_Widgets_Bundle' ) ) {
			SiteOrigin_Widgets_Bundle::single()->activate_widget( 'widget-open-position' );
			set_theme_mod( 'so_custom_widgets_activated', true );
		}
	}


	/**
	 * Set Featured Page widget fields (ProteusWidgets)
	 */
	function set_featured_page_fields( $fields ) {
		$fields['tag'] = true;
		return $fields;
	}


	/**
	 * Set Steps widget fields (ProteusWidgets)
	 */
	function set_steps_widget_settings( $fields ) {
		$fields['use_icons'] = false;
		return $fields;
	}


	/**
	 * Set button shortcode attributes (pt-shortcodes plugin)
	 */
	function pt_button_shortcode_attributes( $attribute_array ) {
		$attribute_array['dashed'] = false;

		return $attribute_array;
	}


	/**
	 * Set button shortcode output (pt-shortcodes plugin)
	 */
	function pt_button_shortcode_output( $default_output, $atts, $content ) {
		return sprintf(
			'<a class="btn  %1$s%2$s%3$s%4$s%9$s" href="%5$s" target="%6$s">%7$s %8$s</a>',
			'btn-' . esc_attr( strtolower( $atts['style'] ) ),
			'rounded' == $atts['corners'] ? '  btn-rounded' : '',
			'true' == $atts['fullwidth'] ? '  col-xs-12' : '',
			! empty( $atts['class'] ) ? '  ' . esc_attr( $atts['class'] ) : '',
			isset( $atts['href'] ) ? esc_url( $atts['href'] ) : '#',
			esc_attr( $atts['target'] ),
			isset( $atts['fa'] ) ? '<i class="fa ' . esc_attr( $atts['fa'] )  . '"></i> ' : '',
			wp_kses_post( $content ),
			empty( $atts['dashed'] ) ? '' : '  btn-dashed'
		);
	}

	/**
	 * Define demo import files for One Click Demo Import plugin.
	 */
	function ocdi_import_files() {
		return array(
			array(
				'import_file_name'       => 'Auto Import',
				'import_file_url'        => 'http://artifacts.proteusthemes.com/xml-exports/auto-latest.xml',
				'import_widget_file_url' => 'http://artifacts.proteusthemes.com/json-widgets/auto.json'
			),
		);
	}


	/**
	 * After import theme setup for One Click Demo Import plugin.
	 */
	function ocdi_after_import_setup() {

		// Menus to Import and assign.
		$main_menu   = get_term_by( 'name', 'Main Menu', 'nav_menu' );
		$footer_menu = get_term_by( 'name', 'Footer Menu', 'nav_menu' );

		set_theme_mod( 'nav_menu_locations', array(
				'main-menu'   => $main_menu->term_id,
				'footer-menu' => $footer_menu->term_id,
			)
		);

		// Set options for front page and blog page.
		$front_page_id = get_page_by_title( 'Home' );
		$blog_page_id  = get_page_by_title( 'News' );

		update_option( 'show_on_front', 'page' );
		update_option( 'page_on_front', $front_page_id->ID );
		update_option( 'page_for_posts', $blog_page_id->ID );

		// Set options for Breadcrumbs NavXT
		$breadcrumbs_settings = get_option( 'bcn_options', array() );
		$breadcrumbs_settings['hseparator'] = '';
		$shop_page = get_page_by_title( 'Shop' );
		if ( ! is_null( $shop_page ) ) {
			$breadcrumbs_settings['apost_product_root'] = $shop_page->ID;
		}
		$breadcrumbs_settings['bpost_product_archive_display'] = false;
		$projects_page = get_page_by_title( 'Used Cars' );
		if ( ! is_null( $projects_page ) ) {
			$breadcrumbs_settings['apost_portfolio_root'] = $projects_page->ID;
		}
		$breadcrumbs_settings['bpost_portfolio_archive_display'] = false;
		$breadcrumbs_settings['bpost_portfolio_taxonomy_display'] = false;
		update_option( 'bcn_options', $breadcrumbs_settings );

		// Set WooCommerce pages.
		if ( AutoPTHelpers::is_woocommerce_active() ) {
			$shop_page = get_page_by_title( 'Shop' );
			if ( $shop_page ) {
				update_option( 'woocommerce_shop_page_id', $shop_page->ID );
			}

			$cart_page = get_page_by_title( 'Cart' );
			if ( $cart_page ) {
				update_option( 'woocommerce_cart_page_id', $cart_page->ID );
			}

			$checkout_page = get_page_by_title( 'Checkout' );
			if ( $checkout_page ) {
				update_option( 'woocommerce_checkout_page_id', $checkout_page->ID );
			}

			$account_page = get_page_by_title( 'My Account' );
			if ( $account_page ) {
				update_option( 'woocommerce_myaccount_page_id', $account_page->ID );
			}
		}

		// Set logo in customizer.
		set_theme_mod( 'logo_img', get_template_directory_uri() . '/assets/images/logo.png' );

		// Set page header background pattern.
		set_theme_mod( 'page_header_bg_img', get_template_directory_uri() . '/assets/images/dark-pattern.jpg' );

		esc_html_e( 'After import setup ended!', 'auto-pt' );
	}


	/**
	 * Message for manual demo import for One Click Demo Import plugin.
	 */
	function ocdi_message_after_file_fetching_error() {
		return sprintf( esc_html__( 'Please try to manually import the demo data. Here are instructions on how to do that: %sDocumentation: Import XML File%s', 'auto-pt' ), '<a href="https://www.proteusthemes.com/docs/auto/#import-xml-file" target="_blank">', '</a>' );
	}


	/**
	 * Add PW widgets to Page Builder group and add icon class.
	 *
	 * @param array $widgets All widgets in page builder list of widgets.
	 *
	 * @return array
	 */
	function add_icons_to_page_builder_for_pw_widgets( $widgets ) {
		foreach ( $widgets as $class => $widget ) {
			if ( strstr( $widget['title'], 'ProteusThemes:' ) ) {
				$widgets[ $class ]['icon']   = 'pw-pb-widget-icon';
				$widgets[ $class ]['groups'] = array( 'pw-widgets' );
			}
		}

		return $widgets;
	}


	/**
	 * Add another tab section in the Page Builder "add new widget" dialog.
	 *
	 * @param array $tabs Existing tabs.
	 *
	 * @return array
	 */
	function siteorigin_panels_add_widgets_dialog_tabs( $tabs ) {
		$tabs['pw_widgets'] = array(
			'title' => esc_html__( 'ProteusThemes Widgets', 'auto-pt' ),
			'filter' => array(
				'groups' => array( 'pw-widgets' ),
			),
		);

		return $tabs;
	}

	/**
	 * Set the mobile menu button class for the sticky menu.
	 */
	function pt_sticky_menu_mobile_menu_button_class() {
		return 'btn-dark';
	}

	/**
	 * Change the page ID in the Featured Page widgets, when duplicating a page (with this widgets in it) to a new language.
	 *
	 * @see https://wpml.org/documentation/support/wpml-coding-api/wpml-hooks-reference/#hook-645257
	 *
	 * @param $value_to_filter
	 * @param $target_language
	 * @param $meta_data
	 *
	 * @return string
	 */
	public function wpml_change_proteus_widget_ids_upon_duplication( $value_to_filter, $target_language, $meta_data ) {
		if ( ! isset( $meta_data['key'] ) || 'panels_data' !== $meta_data['key'] ) {
			return $value_to_filter;
		}

		$new_value = maybe_unserialize( $value_to_filter );

		if ( ! is_array( $new_value ) || empty( $new_value ) || empty( $new_value['widgets'] ) ) {
			return $value_to_filter;
		}

		$new_value['widgets'] = array_map( function( $widget ) use ( $target_language ) {
			if ( isset( $widget['panels_info']['class'] ) && 'PW_Featured_Page' === $widget['panels_info']['class'] ) {
				$widget['page_id'] = apply_filters( 'wpml_object_id', absint( $widget['page_id'] ), 'page', true, $target_language );
			}

			return $widget;
		}, $new_value['widgets'] );

		return serialize( $new_value );
	}
}

// Single instance.
$autopt_filters = new AutoPTFilters();
