<?php
/**
 * Register sidebars for Auto
 *
 * @package auto-pt
 */

function autopt_sidebars() {
	// Blog Sidebar.
	register_sidebar(
		array(
			'name'          => esc_html__( 'Blog Sidebar', 'auto-pt' ),
			'id'            => 'blog-sidebar',
			'description'   => esc_html__( 'Sidebar on the blog layout.', 'auto-pt' ),
			'class'         => 'blog  sidebar',
			'before_widget' => '<div class="widget  %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="sidebar__headings">',
			'after_title'   => '</h4>',
		)
	);

	// Regular Page Sidebar.
	register_sidebar(
		array(
			'name'          => esc_html__( 'Regular Page Sidebar', 'auto-pt' ),
			'id'            => 'regular-page-sidebar',
			'description'   => esc_html__( 'Sidebar on the regular page.', 'auto-pt' ),
			'class'         => 'sidebar',
			'before_widget' => '<div class="widget  %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="sidebar__headings">',
			'after_title'   => '</h4>',
		)
	);

	// Header Widgets.
	register_sidebar(
		array(
			'name'          => esc_html__( 'Header', 'auto-pt' ),
			'id'            => 'header-widgets',
			'description'   => esc_html__( 'Header widget area for Icon Box, Buttons, Social Icons or Skype Button.', 'auto-pt' ),
			'before_widget' => '<div class="widget  %2$s">',
			'after_widget'  => '</div>',
		)
	);

	// Navigation Widgets.
	register_sidebar(
		array(
			'name'          => esc_html__( 'Navigation', 'auto-pt' ),
			'id'            => 'navigation-widgets',
			'description'   => esc_html__( 'Navigation widget area for Social Icons.', 'auto-pt' ),
			'before_widget' => '<div class="widget  %2$s">',
			'after_widget'  => '</div>',
		)
	);

	// WooCommerce shop sidebar.
	if ( AutoPTHelpers::is_woocommerce_active() ) {
		register_sidebar(
			array(
				'name'          => esc_html__( 'Shop Sidebar' , 'auto-pt' ),
				'id'            => 'shop-sidebar',
				'description'   => esc_html__( 'Sidebar for the shop page' , 'auto-pt' ),
				'class'         => 'sidebar',
				'before_widget' => '<div class="widget  %2$s">',
				'after_widget'  => '</div>',
				'before_title'  => '<h4 class="sidebar__headings">',
				'after_title'   => '</h4>',
			)
		);
	}

	// Footer.
	$footer_widgets_num = count( AutoPTHelpers::footer_widgets_layout_array() );

	// Only register if not 0.
	if ( $footer_widgets_num > 0 ) {
		register_sidebar(
			array(
				'name'          => esc_html__( 'Footer Left', 'auto-pt' ),
				'id'            => 'footer-widgets',
				'description'   => sprintf( esc_html__( 'Footer left area works best with %d widgets. This number can be changed in the Appearance &rarr; Customize &rarr; Theme Options &rarr; Footer.', 'auto-pt' ), $footer_widgets_num ),
				'before_widget' => '<div class="col-xs-12  col-lg-__col-num__"><div class="widget  %2$s">', // __col-num__ is replaced dynamically in filter 'dynamic_sidebar_params'
				'after_widget'  => '</div></div>',
				'before_title'  => '<h6 class="footer-top__headings">',
				'after_title'   => '</h6>',
			)
		);
	}

	// Footer Dark Widgets.
	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer Right (dark)', 'auto-pt' ),
			'id'            => 'footer-dark-widgets',
			'description'   => esc_html__( 'Footer right area with dark pattern works best with one textarea widget. Footer Left will take 100% of width if you leave this widget area empty.', 'auto-pt' ),
			'before_widget' => '<div class="widget  %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h6 class="footer-top__headings">',
			'after_title'   => '</h6>',
		)
	);
}
add_action( 'widgets_init', 'autopt_sidebars' );
