<?php

/**
 * Icon Box with Popover container content element for the Visual Composer editor,
 * that allows nesting of other VC content elements
 */

if ( ! class_exists( 'PT_VC_Container_Icon_Box_With_Popover' ) ) {
	class PT_VC_Container_Icon_Box_With_Popover extends PT_VC_Shortcode {

		// Basic shortcode settings
		function shortcode_name() { return 'pt_vc_container_icon_box_with_popover'; }

		// Initialize the shortcode by calling the parent constructor
		public function __construct() {
			parent::__construct();
		}

		// Overwrite the register_shortcode function from the parent class
		public function register_shortcode( $atts, $content = null ) {
			$atts = shortcode_atts( array(
				'title' => '',
				'text'  => '',
				'icon'  => 'fa fa-home',
				), $atts );

			ob_start();
		?>
			<div class="widget-icon-box-with-popover">
				<div class="popover-icon-box  js-popover-icon-box">
					<i class="<?php echo esc_attr( $atts['icon'] ); ?>"></i>
					<div class="popover-icon-box__text">
						<h4 class="popover-icon-box__title"><?php echo wp_kses_post( $atts['title'] ); ?></h4>
						<span class="popover-icon-box__subtitle"><?php echo wp_kses_post( $atts['text'] ); ?></span>
						<button class="btn  popover-icon-box__button"></button>
					</div>
				</div>
				<div class="popover-icon-box-content">
					<?php echo do_shortcode( shortcode_unautop( $content ) ); ?>
				</div>
			</div>
		<?php
			return ob_get_clean();
		}

		// Overwrite the vc_map_shortcode function from the parent class
		public function vc_map_shortcode() {
			vc_map( array(
				'name'            => __( 'Icon Box with Popover', 'auto-pt' ),
				'base'            => $this->shortcode_name(),
				'category'        => __( 'Content', 'auto-pt' ),
				'icon'            => get_template_directory_uri() . '/vendor/proteusthemes/visual-composer-elements/assets/images/pt.svg',
				'content_element' => true,
				'is_container'    => true,
				'js_view'         => 'VcColumnView',
				'params'          => array(
					array(
						'type'       => 'textfield',
						'holder'     => 'div',
						'heading'    => __( 'Title', 'auto-pt' ),
						'param_name' => 'title',
					),
					array(
						'type'       => 'textfield',
						'heading'    => __( 'Text', 'auto-pt' ),
						'param_name' => 'text',
					),
					array(
						'type'        => 'iconpicker',
						'heading'     => _x( 'Icon', 'backend', 'auto-pt' ),
						'param_name'  => 'icon',
						'value'       => 'fa fa-home',
						'description' => _x( 'Select icon from library.', 'backend', 'auto-pt' ),
						'settings'    => array(
							'emptyIcon'    => false, // default true, display an "EMPTY" icon?
							'iconsPerPage' => 100, // default 100, how many icons per/page to display
						),
					),
				)
			) );
		}
	}

	// Initialize the class
	new PT_VC_Container_Icon_Box_With_Popover;

	// The "container" content element should extend WPBakeryShortCodesContainer class to inherit all required functionality
	if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
		class WPBakeryShortCode_Pt_Vc_Container_Icon_Box_With_Popover extends WPBakeryShortCodesContainer {}
	}
}