<?php

/**
 * Pricing List item content element for the Visual Composer editor,
 * that can only be used in the Pricing list container
 */

if ( ! class_exists( 'PT_VC_Pricing_List' ) ) {
	class PT_VC_Pricing_List extends PT_VC_Shortcode {

		// Basic shortcode settings
		function shortcode_name() { return 'pt_vc_pricing_list'; }

		// Initialize the shortcode by calling the parent constructor
		public function __construct() {
			parent::__construct();
		}

		// Overwrite the register_shortcode function from the parent class
		public function register_shortcode( $atts, $content = null ) {
			$atts = shortcode_atts( array(
				'badge'       => '',
				'title'       => '',
				'price'       => '',
				), $atts );

			$atts['description'] = $content;

			// The PHP_EOL is added so that it can be used as a separator between multiple items
			return PHP_EOL . json_encode( $atts );
		}

		// Overwrite the vc_map_shortcode function from the parent class
		public function vc_map_shortcode() {
			vc_map( array(
				'name'     => __( 'Pricing List Item', 'auto-pt' ),
				'base'     => $this->shortcode_name(),
				'category' => __( 'Content', 'auto-pt' ),
				'icon'     => get_template_directory_uri() . '/vendor/proteusthemes/visual-composer-elements/assets/images/pt.svg',
				'as_child' => array( 'only' => 'pt_vc_container_pricing_list' ),
				'params'   => array(
					array(
						'type'       => 'textfield',
						'heading'    => __( 'Badge:', 'auto-pt' ),
						'param_name' => 'badge',
					),
					array(
						'type'       => 'textfield',
						'holder'     => 'div',
						'heading'    => __( 'Title:', 'auto-pt' ),
						'param_name' => 'title',
					),
					array(
						'type'       => 'textfield',
						'heading'    => __( 'Price:', 'auto-pt' ),
						'param_name' => 'price',
					),
					array(
						'type'       => 'textarea_html',
						'heading'    => __( 'Description:', 'auto-pt' ),
						'param_name' => 'content',
					),
				)
			) );
		}
	}

	// Initialize the class
	new PT_VC_Pricing_List;
}